@@ -1,11 +1,11 @@
-# ABSTRACT: Traverse Class Namespaces
+# ABSTRACT: Namespace Dispatch and Resolution
 
 package Class::Forward;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.100004'; # VERSION
+our $VERSION = '0.100005'; # VERSION
 
 use Exporter ();
 
@@ -220,32 +220,36 @@ __END__
 
 =head1 NAME
 
-Class::Forward - Traverse Class Namespaces
+Class::Forward - Namespace Dispatch and Resolution
 
 =head1 VERSION
 
-version 0.100004
+version 0.100005
 
 =head1 SYNOPSIS
 
     use Class::Forward;
 
-    my $resolv = Class::Forward->new(namespace => 'MyApp');
-
-    # returns a MyApp::Data instance
-    my $data  = $resolv->forward('data.new');
-
-    # returns the string /myapp/data
-    my $string = $resolv->reverse('data.new');
+    # create a resolution object
+    my $res = Class::Forward->new(namespace => 'MyApp');
 
     # returns MyApp::Data
-    say $resolv->forward($string);
+    say $res->forward('data');
+
+    # returns a MyApp::Data instance
+    my $data  = $res->forward('data.new');
+
+    # returns the string /my_app/data
+    my $string = $res->reverse('data.new');
+
+    # returns MyApp::Data
+    say $res->forward($string);
 
 =head1 DESCRIPTION
 
 Class::Forward is designed to resolve Perl namespaces from shorthand (which is
-simply a file-system path-like specification). Class::Forward can also be used
-to dispatch method calls using said shorthand. See the following exported
+simply a file-path-like specification). Class::Forward can also be used to
+dispatch method calls using said shorthand. See the following exported
 functions for examples on how this can be used.
 
 =head1 EXPORTS
@@ -350,10 +354,10 @@ The reverse method is used to generate path-like shorthand from Perl namespaces.
 
 Class::Forward was designed to provide shorthand and easy access to class
 namespaces in an environment where you're dealing with a multitude of long
-well-named classes. In that vein, is provides an alternative to modules like
-L<aliased>, L<aliased::factory>, L<as>, and the like, e.g. modules like
+well-named classes. In that vein, it provides an alternative to modules like
+L<aliased>, L<aliased::factory>, L<as>, and the like, and also modules like
 L<Namespace::Dispatch> which are similar enough to be mentioned but really
-tends to a completely different issue.
+address a completely different issue.
 
 =head1 AUTHOR
 
